@@ -58,12 +58,9 @@ MainWindow::MainWindow(QWidget *parent):
     view->show();
     layout->addWidget(view);
 
-    // Progress
+    // Dialogs
     progress = new Progress(this);
 
-    // Settings dialog
-    settings = new QDialog(this);
-
     // Tool bar actions
 
 #ifdef Q_OS_SYMBIAN
