@@ -32,6 +32,11 @@ Book::Book(const QString &p, QObject *parent): QObject(parent), loaded(false)
     }
 }
 
+Book::~Book()
+{
+    close();
+}
+
 QString Book::path()
 {
     return mPath;
@@ -500,7 +505,7 @@ bool Book::extractMetaData()
 {
     QStringList excludedExtensions;
     excludedExtensions << ".html" << ".xhtml" << ".xht" << ".htm" << ".gif"
-            << ".png" << ".css";
+            << ".png" << ".css" << "*.ttf" << "mimetype";
     return extract(excludedExtensions);
 }
 
